# rgpio Package

rgpio is a module for Linux Single Board Computers (SBC) which allows control of the General Purpose Input Outputs (GPIO) over a network.

Each SBC must be running the rgpiod daemon.

## Features

* reading and writing GPIO singly and in groups
* software timed PWM and waves
* callbacks on GPIO level change
* notifications via pipe on GPIO level change
* I2C wrapper
* SPI wrapper
* serial link wrapper
* access control
* file handling
* creating and running scripts
* network access

